@@ -21,9 +21,11 @@
  * Thanks to the following contributors :
  *
  * Martin Cizek
- * 
+ *
  */
 
+#include <stdlib.h>
+
 #include <gst/gst.h>
 #include <gst/netbuffer/gstnetbuffer.h>
 
@@ -846,7 +848,7 @@ gst_rtp_bin_create_jitterbuffer (GstRTPBin * rtp_bin)
       jb_name = "rtpjitterbuffer";
 
     rtpjitterbuffer = gst_element_factory_make (jb_name,
-            NULL);
+            "jitterbuffer");
     if (rtpjitterbuffer == NULL) {
       GST_WARNING("Could not create %s element", jb_name);
       return NULL;
