@@ -5,6 +5,7 @@
 
 #include "gstdtmfsrc.h"
 #include "gstrtpdtmfsrc.h"
+#include "gstrtpdtmfdepay.h"
 
 
 static gboolean
@@ -17,6 +18,9 @@ plugin_init (GstPlugin * plugin)
     return FALSE;
 
 
+  if (!gst_rtp_dtmf_depay_plugin_init (plugin))
+    return FALSE;
+
   return TRUE;
 }
 
