@@ -194,7 +194,7 @@ GST_STATIC_PAD_TEMPLATE ("src",
         "payload = (int) [ 96, 127 ], "
         "clock-rate = (int) [ 0, MAX ], "
         "ssrc = (int) [ 0, MAX ], "
-        "encoding-name = (string) \"telephone-event\"")
+        "encoding-name = (string) \"TELEPHONE-EVENT\"")
     /*  "events = (string) \"1-16\" */
 
     );
@@ -698,7 +698,7 @@ gst_rtp_dtmf_src_create (GstBaseSrc * basesrc, guint64 offset,
         case RTP_DTMF_EVENT_TYPE_START:
           dtmfsrc->first_packet = TRUE;
           dtmfsrc->last_packet = FALSE;
-          /* Set the redundanc on the first packet */
+          /* Set the redundancy on the first packet */
           dtmfsrc->redundancy_count = dtmfsrc->packet_redundancy;
           gst_rtp_dtmf_prepare_timestamps (dtmfsrc);
 
@@ -742,7 +742,7 @@ gst_rtp_dtmf_src_create (GstBaseSrc * basesrc, guint64 offset,
           case RTP_DTMF_EVENT_TYPE_STOP:
             dtmfsrc->first_packet = FALSE;
             dtmfsrc->last_packet = TRUE;
-            /* Set the redundanc on the last packet */
+            /* Set the redundancy on the last packet */
             dtmfsrc->redundancy_count = dtmfsrc->packet_redundancy;
             break;
 
@@ -857,7 +857,7 @@ gst_rtp_dtmf_src_negotiate (GstBaseSrc * basesrc)
   srccaps = gst_caps_new_simple ("application/x-rtp",
       "media", G_TYPE_STRING, "audio",
       "clock-rate", G_TYPE_INT, dtmfsrc->clock_rate,
-      "encoding-name", G_TYPE_STRING, "telephone-event", NULL);
+      "encoding-name", G_TYPE_STRING, "TELEPHONE-EVENT", NULL);
 
   /* the peer caps can override some of the defaults */
   peercaps = gst_pad_peer_get_caps (GST_BASE_SRC_PAD (basesrc));
