@@ -530,7 +530,7 @@ async_jitter_queue_pop_intern_unlocked (AsyncJitterQueue * queue)
       {
         /* Let's wait until the high threshold is reached */
         while (!g_queue_peek_tail (queue->queue) || queue->pop_blocking) {
-          g_debug ("Sink needs buffer, must wait for buffering to stop");
+          //g_debug ("Sink needs buffer, must wait for buffering to stop");
           queue->underruns++;
           queue->waiting_threads++;
           g_cond_wait(queue->cond, queue->mutex);
@@ -545,7 +545,7 @@ async_jitter_queue_pop_intern_unlocked (AsyncJitterQueue * queue)
     else
     {
       while (queue->pop_blocking && !g_queue_peek_tail (queue->queue)) {
-        g_debug ("No packets available for sink! waiting");
+        //g_debug ("No packets available for sink! waiting");
         queue->waiting_threads++;
         queue->underruns++;
         g_cond_wait(queue->cond, queue->mutex);
@@ -746,3 +746,28 @@ async_jitter_queue_set_blocking_unlocked (AsyncJitterQueue * queue,
   if (queue->waiting_threads > 0)
     g_cond_broadcast (queue->cond);
 }
+
+/**
+ * async_jitter_queue_flush_unlocked:
+ * @queue: a #AsyncJitterQueue.
+ * @free_func: a function to call to free the elements
+ * @user_data: user data passed to @free_func
+ *
+ * This functions empties the queue, but does not touch the other threads,
+ * its mostly used when the sequence numbers and timestamps are reset
+ */
+
+void
+async_jitter_queue_flush_unlocked (AsyncJitterQueue * queue,
+    GFunc free_func, gpointer user_data)
+{
+  gpointer elem;
+
+  while ((elem = g_queue_pop_head (queue->queue)))
+  {
+    if (free_func)
+    {
+      free_func (elem, user_data);
+    }
+  }
+}
