@@ -126,8 +126,11 @@ void          async_jitter_queue_set_flushing_unlocked   (AsyncJitterQueue* queu
 void          async_jitter_queue_unset_flushing_unlocked (AsyncJitterQueue* queue);
 void          async_jitter_queue_set_blocking_unlocked   (AsyncJitterQueue* queue,
                                                           gboolean blocking);
-guint32
-async_jitter_queue_length_ts_units_unlocked (AsyncJitterQueue *queue);
+guint32       async_jitter_queue_length_ts_units_unlocked (AsyncJitterQueue *queue);
+
+void          async_jitter_queue_flush_unlocked (AsyncJitterQueue * queue,
+                                                 GFunc free_func,
+                                                 gpointer user_data);
 
 G_END_DECLS
 
