@@ -164,13 +164,19 @@ enum
 #define GST_QUERY_JB_STATS      "jitterbuffer-statistics"
 #define GST_QUERY_JB_STATS_DESC "Query for jitterbuffer statistics"
 
+/* Any seqnum jump larger than this value is invalid */
+#define MAX_SEQNUM_JUMP                 100
+/* The JB will be reset after this number of consecutive invalid seqnums */
+#define MIN_VALID_PACKETS_FOR_RESET     5
+
 enum
 {
   PROP_0,
   PROP_LATENCY,
   PROP_LOW_THRESHOLD,
   PROP_HIGH_THRESHOLD,
-  PROP_DROP_ON_LATENCY
+  PROP_DROP_ON_LATENCY,
+  PROP_HOLD
 };
 
 struct _GstRTPJitterBufferPrivate
@@ -182,6 +188,7 @@ struct _GstRTPJitterBufferPrivate
   /* properties */
   guint latency_ms;
   gboolean drop_on_latency;
+  gboolean on_hold;
 
   /* the last seqnum we pushed out */
   guint32 last_popped_seqnum;
@@ -200,6 +207,14 @@ struct _GstRTPJitterBufferPrivate
   GstClockID clock_id;
   guint32 waiting_seqnum;
 
+  /* for resync after an seqnum jump */
+  /* seqnum of last valid packet received */
+  guint16 last_valid_seqnum;
+  /* if there was a seqnum jump, this is the next seqnum to expect */
+  guint16 next_seqnum_after_jump;
+  /* this is the count of sequential seqnums received */
+  guint32 valid_packets_after_jump;
+
   /* some accounting */
   guint64 num_packets;
   guint64 num_late;
@@ -321,6 +336,16 @@ gst_rtp_jitter_buffer_class_init (GstRTPJitterBufferClass * klass)
           "Drop buffers when maximum latency is reached",
           "Tells the jitterbuffer to never exceed the given latency in size",
           DEFAULT_DROP_ON_LATENCY, G_PARAM_READWRITE));
+  /**
+   * GstRTPJitterBuffer::hold:
+   * 
+   * Hold the call by pausing the streaming task
+   */
+  g_object_class_install_property (gobject_class, PROP_HOLD,
+      g_param_spec_boolean ("hold",
+          "Hold the call",
+          "Hold the call by pausing the streaming task",
+          FALSE, G_PARAM_READWRITE));
 
   g_object_class_install_property (gobject_class, PROP_HIGH_THRESHOLD,
       g_param_spec_float ("high_threshold", "The high threshold",
@@ -801,8 +826,12 @@ gst_rtp_jitter_buffer_sink_event (GstPad * pad, GstEvent * event)
       /* check for flushing, we need to discard the event and return FALSE when
        * we are flushing */
       ret = priv->srcresult == GST_FLOW_OK;
-      if (ret)
-        async_jitter_queue_push_unlocked (priv->queue, event);
+      if (ret) {
+        if (priv->latency_ms == 0)
+          gst_pad_push_event (priv->srcpad, event);
+        else
+          async_jitter_queue_push_unlocked (priv->queue, event);
+      }
       else
         gst_event_unref (event);
       async_jitter_queue_unlock (priv->queue);
@@ -907,6 +936,54 @@ gst_rtp_jitter_buffer_chain (GstPad * pad, GstBuffer * buffer)
   if (ret != GST_FLOW_OK)
     goto out_flushing;
 
+  /* Lets see if there is any sequence number re-setting done */
+  /* First, we check if there was a valid seqnum
+   * Then we compare the last valid seqnum with that of the current packet
+   * and we check if the "jump" is larger than the maximum accepted jump
+   * but we also check if its not a roll-over
+   */
+  if (priv->last_valid_seqnum &&
+      abs (priv->last_valid_seqnum - seqnum) > MAX_SEQNUM_JUMP &&
+      abs (priv->last_valid_seqnum - seqnum) < G_MAXUINT16 - MAX_SEQNUM_JUMP)
+  {
+    if (seqnum == priv->next_seqnum_after_jump)
+    {
+      priv->next_seqnum_after_jump++;
+      priv->valid_packets_after_jump++;
+      if (priv->valid_packets_after_jump > MIN_VALID_PACKETS_FOR_RESET)
+      {
+        /* We had enough valid seqnums in the new streams, lets flush the
+         * JB and start anew
+         */
+        GST_DEBUG_OBJECT (jitterbuffer,
+                          "Flushing queue, resetting sequence numbers");
+        priv->last_popped_seqnum = -1;
+        priv->next_seqnum = -1;
+        priv->next_seqnum_after_jump = 0;
+        priv->valid_packets_after_jump = 0;
+        async_jitter_queue_flush_unlocked (jitterbuffer->priv->queue,
+                                           (GFunc) free_func, jitterbuffer);
+      }
+      else
+      {
+        goto invalid_seqnum;
+      }
+    }
+    else
+    {
+      priv->next_seqnum_after_jump = seqnum + 1;
+      priv->valid_packets_after_jump = 0;
+      goto invalid_seqnum;
+    }
+  }
+  else
+  {
+    priv->next_seqnum_after_jump = 0;
+    priv->valid_packets_after_jump = 0;
+  }
+
+  priv->last_valid_seqnum = seqnum;
+
   /* let's check if this buffer is too late, we cannot accept packets with
    * bigger seqnum than the one we already pushed. */
   if (priv->last_popped_seqnum != -1) {
@@ -920,8 +997,10 @@ gst_rtp_jitter_buffer_chain (GstPad * pad, GstBuffer * buffer)
     if (async_jitter_queue_length_ts_units_unlocked (priv->queue) >=
         priv->latency_ms * priv->clock_rate / 1000) {
       guint32 latency_ts_units;
-  
-      priv->times_overrun++;
+
+      if (!priv->on_hold) {
+        priv->times_overrun++;
+      }
       GST_DEBUG_OBJECT (jitterbuffer, "Queue full, dropping old packet #%d",
           seqnum);
 
@@ -1005,6 +1084,14 @@ duplicate:
     gst_buffer_unref (buffer);
     goto finished;
   }
+invalid_seqnum:
+  {
+    GST_DEBUG_OBJECT (jitterbuffer, "Received packet with invalid seqnum %u,"
+                      " last was %u", seqnum, priv->last_valid_seqnum);
+    priv->num_late++;
+    gst_buffer_unref (buffer);
+    goto finished;
+  }
 }
 
 /**
@@ -1219,7 +1306,6 @@ no_elem:
   {
     /* store result, we are flushing now */
     GST_DEBUG_OBJECT (jitterbuffer, "Pop returned NULL, we're flushing");
-    priv->srcresult = GST_FLOW_WRONG_STATE;
     gst_pad_pause_task (priv->srcpad);
     async_jitter_queue_unlock (priv->queue);
     return;
@@ -1261,6 +1347,10 @@ gst_rtp_jitter_buffer_src_query (GstPad * pad, GstQuery * query)
   jitterbuffer = GST_RTP_JITTER_BUFFER (gst_pad_get_parent (pad));
   priv = jitterbuffer->priv;
 
+  if (stats_query_type == GST_QUERY_TYPE (query)) {
+    return gst_rtp_jitter_buffer_sink_query (pad, query);
+  }
+
   switch (GST_QUERY_TYPE (query))
   {
 #if GST_VERSION_NANO
@@ -1417,6 +1507,31 @@ gst_rtp_jitter_buffer_set_property (GObject * object,
       jitterbuffer->priv->drop_on_latency = g_value_get_boolean (value);
       break;
     }
+    case PROP_HOLD:
+    {
+      gboolean old_value = jitterbuffer->priv->on_hold;
+      jitterbuffer->priv->on_hold = g_value_get_boolean (value);
+      if (old_value != jitterbuffer->priv->on_hold) {
+        if (jitterbuffer->priv->on_hold) {
+          async_jitter_queue_lock (jitterbuffer->priv->queue);
+          GST_DEBUG_OBJECT (jitterbuffer, "Holding call : Pausing task on srcpad");
+          async_jitter_queue_set_flushing_unlocked (jitterbuffer->priv->queue,
+              (GFunc) free_func, jitterbuffer);
+          async_jitter_queue_unlock (jitterbuffer->priv->queue);
+
+          gst_pad_pause_task (jitterbuffer->priv->srcpad);
+        } else {
+          async_jitter_queue_lock (jitterbuffer->priv->queue);
+          GST_DEBUG_OBJECT (jitterbuffer, "Unholding call : Starting task on srcpad");
+          async_jitter_queue_unset_flushing_unlocked (jitterbuffer->priv->queue);
+          async_jitter_queue_unlock (jitterbuffer->priv->queue);
+
+          gst_pad_start_task (jitterbuffer->priv->srcpad,
+              (GstTaskFunction) gst_rtp_jitter_buffer_loop, jitterbuffer);
+        }
+      }
+      break;
+    }
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
@@ -1444,6 +1559,9 @@ gst_rtp_jitter_buffer_get_property (GObject * object,
     case PROP_DROP_ON_LATENCY:
       g_value_set_boolean (value, jitterbuffer->priv->drop_on_latency);
       break;
+    case PROP_HOLD:
+      g_value_set_boolean (value, jitterbuffer->priv->on_hold);
+      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
