@@ -49,13 +49,18 @@ typedef struct _GstRTPJitterBuffer GstRTPJitterBuffer;
 typedef struct _GstRTPJitterBufferClass GstRTPJitterBufferClass;
 typedef struct _GstRTPJitterBufferPrivate GstRTPJitterBufferPrivate;
 
+/**
+ * GstRTPJitterBuffer:
+ *
+ * Opaque jitterbuffer structure.
+ */
 struct _GstRTPJitterBuffer
 {
   GstElement parent;
 
+  /*< private >*/
   GstRTPJitterBufferPrivate *priv;
 
-  /*< private > */
   gpointer _gst_reserved[GST_PADDING];
 };
 
@@ -63,8 +68,11 @@ struct _GstRTPJitterBufferClass
 {
   GstElementClass parent_class;
 
+  /* signals */
   GstCaps* (*request_pt_map) (GstRTPJitterBuffer *buffer, guint pt);
 
+  void     (*clear_pt_map)   (GstRTPJitterBuffer *buffer);
+
   /*< private > */
   gpointer _gst_reserved[GST_PADDING];
 };
